==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AMinusBinop.h <==
// public final class soot.jimple.parser.node.AMinusBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 38173c825f68b5d0 soot_jimple_parser_node_AMinusBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_AMinusBinop_H_
#define _JC_soot_jimple_parser_node_AMinusBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TMinus$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AMinusBinop$sub_refs	_jc_soot_jimple_parser_node_AMinusBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AMinusBinop$sub_nonrefs	_jc_soot_jimple_parser_node_AMinusBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AMinusBinop$refs	_jc_soot_jimple_parser_node_AMinusBinop$refs;
typedef struct _jc_soot_jimple_parser_node_AMinusBinop$nonrefs	_jc_soot_jimple_parser_node_AMinusBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AMinusBinop$object	_jc_soot_jimple_parser_node_AMinusBinop$object;

typedef const struct _jc_soot_jimple_parser_node_AMinusBinop$vmethods	_jc_soot_jimple_parser_node_AMinusBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AMinusBinop$vtable	_jc_soot_jimple_parser_node_AMinusBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_AMinusBinop$vtype	_jc_soot_jimple_parser_node_AMinusBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AMinusBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *);
extern void _jc_soot_jimple_parser_node_AMinusBinop$method$_init$ea9416a5b84c372a(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *, struct _jc_soot_jimple_parser_node_TMinus$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AMinusBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AMinusBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *);
extern struct _jc_soot_jimple_parser_node_TMinus$object *_jc_soot_jimple_parser_node_AMinusBinop$method$getMinus$9aea657cb808dd50(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *);
extern void _jc_soot_jimple_parser_node_AMinusBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AMinusBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AMinusBinop$method$setMinus$e5051560bf6de876(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *, struct _jc_soot_jimple_parser_node_TMinus$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AMinusBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AMinusBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AMinusBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AMinusBinop$method_info$getMinus$9aea657cb808dd50;
extern _jc_method _jc_soot_jimple_parser_node_AMinusBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AMinusBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AMinusBinop$method_info$setMinus$e5051560bf6de876;
extern _jc_method _jc_soot_jimple_parser_node_AMinusBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AMinusBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *);
	struct _jc_soot_jimple_parser_node_TMinus$object	*(*getMinus$9aea657cb808dd50)(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setMinus$e5051560bf6de876)(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *, struct _jc_soot_jimple_parser_node_TMinus$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AMinusBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_AMinusBinop$vmethods	soot_jimple_parser_node_AMinusBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_AMinusBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AMinusBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AMinusBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TMinus$object	*__5fminus__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AMinusBinop$refs {
    _jc_soot_jimple_parser_node_AMinusBinop$sub_refs	soot_jimple_parser_node_AMinusBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AMinusBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AMinusBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_AMinusBinop$sub_nonrefs	soot_jimple_parser_node_AMinusBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AMinusBinop$object {
	_jc_soot_jimple_parser_node_AMinusBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AMinusBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_AMinusBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AMinusBinop$vtype _jc_soot_jimple_parser_node_AMinusBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AMinusBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AMinusBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_AMinusBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AMinusBinop.h <==
// public final class soot.jimple.parser.node.AMinusBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 38173c825f68b5d0 soot_jimple_parser_node_AMinusBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_AMinusBinop_H_
#define _JC_soot_jimple_parser_node_AMinusBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TMinus$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AMinusBinop$sub_refs	_jc_soot_jimple_parser_node_AMinusBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AMinusBinop$sub_nonrefs	_jc_soot_jimple_parser_node_AMinusBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AMinusBinop$refs	_jc_soot_jimple_parser_node_AMinusBinop$refs;
typedef struct _jc_soot_jimple_parser_node_AMinusBinop$nonrefs	_jc_soot_jimple_parser_node_AMinusBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AMinusBinop$object	_jc_soot_jimple_parser_node_AMinusBinop$object;

typedef const struct _jc_soot_jimple_parser_node_AMinusBinop$vmethods	_jc_soot_jimple_parser_node_AMinusBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AMinusBinop$vtable	_jc_soot_jimple_parser_node_AMinusBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_AMinusBinop$vtype	_jc_soot_jimple_parser_node_AMinusBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AMinusBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AMinusBinop$method$_init$ea9416a5b84c372a(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *, struct _jc_soot_jimple_parser_node_TMinus$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AMinusBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AMinusBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TMinus$object *_jc_soot_jimple_parser_node_AMinusBinop$method$getMinus$9aea657cb808dd50(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AMinusBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AMinusBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AMinusBinop$method$setMinus$e5051560bf6de876(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *, struct _jc_soot_jimple_parser_node_TMinus$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AMinusBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AMinusBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AMinusBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AMinusBinop$method_info$getMinus$9aea657cb808dd50;
extern _jc_method _jc_soot_jimple_parser_node_AMinusBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AMinusBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AMinusBinop$method_info$setMinus$e5051560bf6de876;
extern _jc_method _jc_soot_jimple_parser_node_AMinusBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AMinusBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TMinus$object	*(*getMinus$9aea657cb808dd50)(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setMinus$e5051560bf6de876)(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *, struct _jc_soot_jimple_parser_node_TMinus$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AMinusBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AMinusBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_AMinusBinop$vmethods	soot_jimple_parser_node_AMinusBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_AMinusBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AMinusBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AMinusBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TMinus$object	*__5fminus__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AMinusBinop$refs {
    _jc_soot_jimple_parser_node_AMinusBinop$sub_refs	soot_jimple_parser_node_AMinusBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AMinusBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AMinusBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_AMinusBinop$sub_nonrefs	soot_jimple_parser_node_AMinusBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AMinusBinop$object {
	_jc_soot_jimple_parser_node_AMinusBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AMinusBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_AMinusBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AMinusBinop$vtype _jc_soot_jimple_parser_node_AMinusBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AMinusBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AMinusBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_AMinusBinop_H_ */
